ETH_CHAIN = 'ETHERIUM'
POLYGON_CHAIN = 'POLYGON'
SOLANA_CHAIN = 'SOLANA'

ETHNET = "https://api.etherscan.io"
POLYGONNET = "https://api.polygonscan.com"
BSCNET = "https://api.bscscan.com/"
